@@ -1,7 +1,16 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
+
+"""
+dycall.exports
+~~~~~~~~~~~~~~
+
+Contains `ExportsFrame` and `ExportsTreeView`.
+"""
+
 from __future__ import annotations
 
 import logging
+import pathlib
 from typing import TYPE_CHECKING
 
 import ttkbootstrap as tk
@@ -11,15 +20,23 @@ from ttkbootstrap.localization import MessageCatalog as MsgCat
 from ttkbootstrap.tableview import Tableview
 
 from dycall.types import Export, PEExport
-from dycall.util import StaticThemedTooltip, get_png, set_app_icon
+from dycall.util import StaticThemedTooltip, get_img
 
 log = logging.getLogger(__name__)
 
 
 class ExportsFrame(ttk.Labelframe):
+    """Contains **Exports** combobox and a button for `ExportsTreeView`.
+
+    Use command line argument `--exp` to select an export from the library on
+    launch. Combobox validates export name.
+
+    TODO: Combobox works like google search (auto-suggest, recents etc.)
+    """
+
     def __init__(
         self,
-        parent: tk.Window,
+        root: tk.Window,
         selected_export: tk.StringVar,
         sort_order: tk.StringVar,
         output: tk.StringVar,
@@ -27,12 +44,13 @@ class ExportsFrame(ttk.Labelframe):
         is_loaded: tk.BooleanVar,
         is_native: tk.BooleanVar,
         is_reinitialised: tk.BooleanVar,
+        lib_path: tk.StringVar,
         exports: list[Export],
     ):
         log.debug("Initalising")
 
         super().__init__(text=MsgCat.translate("Exports"))
-        self.__parent = parent
+        self.__root = root
         self.__selected_export = selected_export
         self.__sort_order = sort_order
         self.__output = output
@@ -40,27 +58,25 @@ class ExportsFrame(ttk.Labelframe):
         self.__is_loaded = is_loaded
         self.__is_native = is_native
         self.__is_reinitialised = is_reinitialised
+        self.__lib_path = lib_path
         self.__exports = exports
         self.__export_names: list[str] = []
 
-        cb_validator = self.register(self.cb_validate)
         self.cb = cb = ttk.Combobox(
             self,
             state="disabled",
             textvariable=selected_export,
             validate="focusout",
-            validatecommand=(cb_validator, "%P"),
+            validatecommand=(self.register(self.cb_validate), "%P"),
         )
         # ! cb.bind("<Return>", lambda *_: self.cb_validate)  # Doesn't work
         cb.bind("<<ComboboxSelected>>", self.cb_selected)
 
-        self.__list_png = get_png("list.png")
+        self.__list_png = get_img("list.png")
         self.lb = lb = ttk.Label(self, image=self.__list_png)
         lb.bind(
             "<Enter>",
-            lambda *_: StaticThemedTooltip(
-                lb, parent, MsgCat.translate("List of exports")
-            ),
+            lambda *_: StaticThemedTooltip(lb, MsgCat.translate("List of exports")),
         )
         lb.bind("<ButtonRelease-1>", lambda *_: status.set("Load a library first!"))
 
@@ -82,9 +98,9 @@ class ExportsFrame(ttk.Labelframe):
         log.debug("%s selected", self.__selected_export.get())
         self.__output.set("")
         if self.__is_native.get():
-            self.__parent.event_generate("<<ToggleFunctionFrame>>", state=1)
+            self.__root.event_generate("<<ToggleFunctionFrame>>", state=1)
         else:
-            self.__parent.event_generate("<<ToggleFunctionFrame>>", state=0)
+            self.__root.event_generate("<<ToggleFunctionFrame>>", state=0)
 
     def cb_validate(self, *_) -> bool:
         """Callback to handle keyboard events on **Exports** combobox.
@@ -102,7 +118,7 @@ class ExportsFrame(ttk.Labelframe):
                 if exp in self.__export_names:
                     self.cb_selected()
                     return True
-                self.__parent.event_generate("<<ToggleFunctionFrame>>", state=1)
+                self.__root.event_generate("<<ToggleFunctionFrame>>", state=1)
                 return False
         return True
 
@@ -126,7 +142,6 @@ class ExportsFrame(ttk.Labelframe):
             self.__status.set(f"{num_exports} exports found")
             failed = []
             for exp in exports:
-
                 if isinstance(exp, PEExport):
                     if hasattr(exp, "exc"):
                         failed.append(exp.name)
@@ -134,7 +149,7 @@ class ExportsFrame(ttk.Labelframe):
                 Messagebox.show_warning(
                     f"These export names couldn't be demangled: {failed}",
                     "Demangle Errors",
-                    parent=self.__parent,
+                    parent=self.__root,
                 )
         self.__export_names = names = list(e.demangled_name for e in exports)
         self.set_state()
@@ -145,7 +160,7 @@ class ExportsFrame(ttk.Labelframe):
                 err = "%s not found in export names"
                 log.error(err, selected_export)
                 Messagebox.show_error(
-                    err % selected_export, "Export not found", parent=self.__parent
+                    err % selected_export, "Export not found", parent=self.__root
                 )
                 self.cb.set("")
             else:
@@ -153,10 +168,15 @@ class ExportsFrame(ttk.Labelframe):
                 self.cb_selected()
         self.lb.configure(cursor="hand2")
         self.lb.bind(
-            "<ButtonRelease-1>", lambda *_: ExportsTreeView(self.__exports), add=False
+            "<ButtonRelease-1>",
+            lambda *_: ExportsTreeView(
+                self.__exports, pathlib.Path(self.__lib_path.get()).name
+            ),
+            add=False,
         )
 
     def sort(self, *_):
+        """Sorts the list of export names and repopulates the combobox."""
         if self.__is_loaded.get():
             sorter = self.__sort_order.get()
             log.debug("Sorting w.r.t. %s", sorter)
@@ -170,10 +190,22 @@ class ExportsFrame(ttk.Labelframe):
 
 
 class ExportsTreeView(tk.Toplevel):
-    def __init__(self, exports: list[Export]):
+    """Displays detailed information about all the exports of a library.
+
+    Following information is displayed:
+    - Address
+    - Name
+    - Demangled name (whenever available)
+    - Ordinal (Windows only)
+    """
+
+    def __init__(self, exports: list[Export], lib_name: str):
         log.debug("Initialising")
-        super().__init__(title=MsgCat.translate("Exports"), size=(400, 500))
-        set_app_icon(self)
+        super().__init__(
+            title=f"{MsgCat.translate('Exports')} - {lib_name}", size=(400, 500)
+        )
+        self.__old_height = 0
+        self.withdraw()
         coldata = [
             "Address",
             "Name",
@@ -182,7 +214,7 @@ class ExportsTreeView(tk.Toplevel):
         is_pe = isinstance(exports[0], PEExport)
         if is_pe:
             coldata.insert(0, "Ordinal")
-        tv = Tableview(
+        self.__tv = tv = Tableview(
             self,
             searchable=True,
             autofit=True,
@@ -199,4 +231,25 @@ class ExportsTreeView(tk.Toplevel):
                 values.insert(0, e.ordinal)
             tv.insert_row(values=values)
         tv.load_table_data()
+        self.bind(
+            "<F11>",
+            lambda *_: self.attributes(
+                "-fullscreen", not self.attributes("-fullscreen")
+            ),
+        )
+        self.bind("<Configure>", self.resize)
+        self.deiconify()
+        self.focus_set()
         log.debug("Initialised")
+
+    def resize(self, event: tk.tk.Event):
+        """Change the treeview's `pagesize` whenever this window is resized.
+
+        I came up with this because there is no way to show a vertical
+        scrollbar in/for the treeview.
+        """
+        new_height = event.height
+        if event.widget.widgetName == "toplevel" and new_height != self.__old_height:
+            # ! This is an expensive call, avoid it whenever possible
+            self.__tv.pagesize = int(new_height) / 20
+            self.__old_height = new_height
