@@ -1,5 +1,6 @@
-# -*- coding: utf-8 -*-
-"""Check for images and translations."""
+#!/usr/bin/env python3
+
+"""Tests for images and translations."""
 
 from pathlib import Path
 
@@ -9,14 +10,24 @@ root = Path(__file__).parent.parent.resolve()
 
 
 def test_check_translations():
-    """Checks whther all the locale IDs (except English) mentioned in
-    `dycall.util.LCIDS` have a translation file available in the package.
-    """  # noqa: D205, D415
+    """Checks if translations exist and are syntactically correct.
+
+    1. Whether all the locale IDs (except English) mentioned in
+       `dycall.util.LCIDS` have a translation file.
+    2. Checks if the command `::msgcat::mcset` and the correct LCID
+       is present every line.
+    """
     msgs = root / "dycall/msgs"
     lcids = list(LCIDS)
     lcids.remove("en")
     for lcid in lcids:
-        assert Path(msgs / f"{lcid}.msg").is_file()
+        msg = Path(msgs / f"{lcid}.msg")
+        assert msg.is_file()
+        with open(msg, encoding="utf-8") as fp:
+            for line in fp.readlines():
+                command, locale = line.strip().split()[:2]
+                assert command == "::msgcat::mcset"
+                assert locale == lcid
 
 
 def test_check_images():
